========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/oslo.limit.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html


==========
oslo.limit
==========

.. image:: https://img.shields.io/pypi/v/oslo.limit.svg
    :target: https://pypi.python.org/pypi/oslo.limit/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.limit.svg
    :target: https://pypi.python.org/pypi/oslo.limit/
    :alt: Downloads



Oslo.limit is the limit enforcement library to assist with quota calculation.
It aims to provide support for quota enforcement across all OpenStack services.

* Free software: Apache license
* Documentation: https://docs.openstack.org/oslo.limit/latest/
* Source: http://opendev.org/openstack/oslo.limit
* Bugs: http://bugs.launchpad.net/oslo.limit
